==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/SEvaluator__24TopConstant.h <==
// public class soot.shimple.toolkits.scalar.SEvaluator$TopConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 430b138846f45212 soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant
// @dep_class 211464a5376a44bf soot_shimple_toolkits_scalar_SEvaluator__24TopConstant

// header file dependencies
// @dep_header soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

#include "soot/shimple/toolkits/scalar/SEvaluator__24MetaConstant.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_Constant$object;
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object;

typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype;

// Class fields structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct {
	struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object	*constant;
};
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$class_fields;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *);

// Virtual methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *, struct _jc_object *);
extern struct _jc_soot_Type$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method_info$getType$847707b1f3b96fef;

// Static methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$v$9e5d622306b04dbc(_jc_env *);

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *, struct _jc_object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *);
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24TopConstant;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24TopConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24TopConstant;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator__24TopConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/SEvaluator__24TopConstant.h <==
// public class soot.shimple.toolkits.scalar.SEvaluator$TopConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 430b138846f45212 soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant
// @dep_class 211464a5376a44bf soot_shimple_toolkits_scalar_SEvaluator__24TopConstant

// header file dependencies
// @dep_header soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

#include "soot/shimple/toolkits/scalar/SEvaluator__24MetaConstant.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_Constant$object;
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object;

typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype;

// Class fields structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct {
	struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object	*constant;
};
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$fields_struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$class_fields;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method_info$getType$847707b1f3b96fef;

// Static methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$method$v$9e5d622306b04dbc(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24TopConstant;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24TopConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24TopConstant;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator__24TopConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator__24TopConstant_H_ */
